# Generated by Django 2.1.5 on 2019-01-30 14:17

from django.db import migrations
import migrate_sql.operations


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_rounting', '0002_auto_20181221_1409'),
    ]

    operations = [
        migrate_sql.operations.CreateSQL(
            name='subscriber_view',
            sql="DROP VIEW IF EXISTS subscriber CASCADE; CREATE OR REPLACE VIEW subscriber AS  SELECT row_number() OVER () AS id,  c.name AS username,  CAST('' AS VARCHAR) AS domain,  c.password FROM pyfb_endpoint_customer c WHERE c.enabled=True and c.registration=True;",
            reverse_sql='DROP subscriber',
        ),
        migrate_sql.operations.CreateSQL(
            name='address_view',
            sql='DROP VIEW IF EXISTS address CASCADE; CREATE OR REPLACE VIEW address AS SELECT row_number() OVER () AS id, * FROM (  SELECT  1 AS grp,  CAST(LEFT(CAST(c.sip_ip AS VARCHAR), LENGTH(CAST(c.sip_ip AS VARCHAR)) - 3) AS VARCHAR) AS ip_addr,  CAST(RIGHT(CAST(c.sip_ip AS VARCHAR), 2) AS INTEGER) AS mask,  CAST(c.sip_port AS INTEGER) AS port,  CAST(c.name AS VARCHAR) AS tag FROM pyfb_endpoint_customer c WHERE c.enabled=True and c.registration=False UNION ALL SELECT  10 AS grp,  CAST(sg.sip_proxy AS VARCHAR) AS ip_addr,  32 AS mask,  CAST(sg.sip_port AS INTEGER) AS port,  sg.name AS tag FROM pyfb_endpoint_provider sg WHERE sg.enabled=True and sg.register=False) v;',
            reverse_sql='DROP VIEW IF EXISTS address CASCADE ',
        ),
        migrate_sql.operations.CreateSQL(
            name='usrpref_view',
            sql="DROP VIEW IF EXISTS usr_preferences CASCADE; CREATE OR REPLACE VIEW usr_preferences AS SELECT row_number() OVER () AS id, * FROM (  SELECT DISTINCT  c.name AS uuid,  c.name AS username,  CAST('' AS VARCHAR) AS domain,  CAST('grpnormcallee' AS VARCHAR) AS attribute,  CAST(1 AS INT) AS type,  CAST(nrg.dpid_id AS VARCHAR) AS value,  CAST(now() AS timestamp without time zone) AS last_modified FROM pyfb_endpoint_customer c INNER JOIN pyfb_normalization_grp ng   ON ng.id = c.callee_norm_id INNER JOIN pyfb_normalization_rule_grp nrg  ON nrg.dpid_id = ng.id WHERE c.enabled=True UNION ALL   SELECT DISTINCT  c.name AS uuid,  c.name AS username,  CAST('' AS VARCHAR) AS domain,  CAST('grpnormcaller' AS VARCHAR) AS attribute,  CAST(1 AS INT) AS type,  CAST(nrg.dpid_id AS VARCHAR) AS value,  CAST(now() AS timestamp without time zone) AS last_modified FROM pyfb_endpoint_customer c INNER JOIN pyfb_normalization_grp ng   ON ng.id = c.callerid_norm_id INNER JOIN pyfb_normalization_rule_grp nrg  ON nrg.dpid_id = ng.id WHERE c.enabled=True UNION ALL   SELECT DISTINCT  c.name AS uuid,  c.name AS username,  CAST('' AS VARCHAR) AS domain,  CAST('grpnormcalleein' AS VARCHAR) AS attribute,  CAST(1 AS INT) AS type,  CAST(nrg.dpid_id AS VARCHAR) AS value,  CAST(now() AS timestamp without time zone) AS last_modified FROM pyfb_endpoint_customer c INNER JOIN pyfb_normalization_grp ng   ON ng.id = c.callee_norm_in_id INNER JOIN pyfb_normalization_rule_grp nrg  ON nrg.dpid_id = ng.id WHERE c.enabled=True UNION ALL   SELECT DISTINCT  c.name AS uuid,  c.name AS username,  CAST('' AS VARCHAR) AS domain,  CAST('grpnormcallerin' AS VARCHAR) AS attribute,  CAST(1 AS INT) AS type,  CAST(nrg.dpid_id AS VARCHAR) AS value,  CAST(now() AS timestamp without time zone) AS last_modified FROM pyfb_endpoint_customer c INNER JOIN pyfb_normalization_grp ng   ON ng.id = c.callerid_norm_in_id INNER JOIN pyfb_normalization_rule_grp nrg  ON nrg.dpid_id = ng.id WHERE c.enabled=True UNION ALL   SELECT DISTINCT  c.name AS uuid,  c.name AS username,  CAST('' AS VARCHAR) AS domain,  CAST('routinggrp' AS VARCHAR) AS attribute,  CAST(1 AS INT) AS type,  CAST(r.routinggroup_id AS VARCHAR) AS value,  CAST(now() AS timestamp without time zone) AS last_modified FROM pyfb_endpoint_customer c INNER JOIN pyfb_routing_c_routinggrp r   ON r.customer_id = c.customer_id WHERE c.enabled=True) v; ",
            reverse_sql='DROP VIEW IF EXISTS usr_preferences CASCADE; ',
        ),
    ]



from django import forms

from .models import CustomerEndpoint, Codec, ProviderEndpoint


class CustomerEndpointForm(forms.ModelForm):
    class Meta:
        model = CustomerEndpoint
        fields = ['registration', 'password', 'description', 'name', 'rtp_ip', 'sip_ip', 'sip_port', 'max_calls', 'calls_per_second', 'outbound_caller_id_name', 'outbound_caller_id_number', 'force_caller_id', 'masq_caller_id', 'urgency_number', 'insee_code', 'enabled', 'fake_ring', 'cli_debug', 'transcoding_allowed', 'recording_allowed', 'recording_always', 'recording_limit', 'recording_retention', 'sip_transport', 'rtp_transport', 'rtp_tos', 'pai', 'pid', 'ha1', 'ha1b', 'customer', 'callerid_norm', 'callee_norm', 'callerid_norm_in', 'callee_norm_in', 'codec_list']


class CodecForm(forms.ModelForm):
    class Meta:
        model = Codec
        fields = ['name', 'number', 'ptime', 'stereo', 'rfc_name', 'description']


class ProviderEndpointForm(forms.ModelForm):
    class Meta:
        model = ProviderEndpoint
        fields = ['name', 'max_calls', 'enabled', 'prefix', 'suffix', 'username', 'password', 'register', 'sip_proxy', 'sip_transport', 'sip_port', 'realm', 'from_domain', 'expire_seconds', 'retry_seconds', 'caller_id_in_from', 'pid', 'ppi', 'pai', 'calls_per_second', 'rtp_transport', 'rtp_tos', 'provider', 'add_plus_in_caller', 'callerid_norm', 'callee_norm', 'callerid_norm_in', 'callee_norm_in', 'codec_list']



# -*- coding: utf-8 -*-
from django.core.exceptions import ValidationError
from django.db import models
from django.urls import reverse
from django.utils.translation import ugettext_lazy as _

from netaddr import IPNetwork
import re
import random
import string

from model_utils.models import TimeStampedModel
from model_utils import Choices

from partial_index import PartialIndex

from pyfb_company.models import Customer, Provider

from pyfb_normalization.models import NormalizationGrp

from pyfb_kamailio.models import Domain, UacReg

from .validators import validate_cidr


def random_string():
    # Alphanumeric + special characters
    chars = string.ascii_letters + string.digits + string.punctuation

    pwdSize = 25

    return str(''.join((random.choice(chars)) for _ in range(pwdSize)))


class Codec(TimeStampedModel):

    # Fields
    name = models.CharField(_(u"name"), max_length=100, unique=True)
    number = models.PositiveIntegerField(_(u"payload number"), unique=True, help_text=_(u"payload types (PT) for audio encodings"))
    ptime = models.PositiveIntegerField(_(u"ptime"))
    stereo = models.BooleanField(_(u"is stereo ?"), default=False)
    rfc_name = models.CharField(_(u"rfc name"), max_length=30, unique=True, help_text=_(u"format is important !."))
    description = models.TextField(_(u"description"), blank=True, max_length=100)

    class Meta:
        ordering = ('-name',)

    def __str__(self):
        return u'%s' % self.name

    def get_absolute_url(self):
        return reverse('pyfb-endpoint:pyfb_endpoint_codec_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-endpoint:pyfb_endpoint_codec_update', args=(self.pk,))


class CustomerEndpoint(TimeStampedModel):
    """ Customer Endpoint Model """

    # Choices
    SIP_TRANSPORT_CHOICES = Choices(
        'udp',
        'tcp',
        'tls'
    )
    RTP_TRANSPORT_CHOICES = Choices(
        'RTP/AVP',
    )
    TOS_RTP_CHOICES = Choices(
        # reference : https://en.wikipedia.org/wiki/Type_of_service
        (0, '0 - CS0 - 0 Best effort'),
        (160, '160 - CS5 - 5 Critical'),
        (184, '184 - EF - 5 Critical'),
    )

    # Fields
    name = models.CharField(_(u"username"), max_length=50, unique=True, help_text=_(u"Ex.: customer SIP username, etc..."))
    enabled = models.BooleanField(_(u"enabled / disabled"), default=True)
    registration = models.BooleanField(_(u"registration"), default=True, help_text=_(u"Is registration needed for calling ? True, the phone needs to register with correct username/password. If false, you must specify a CIDR in SIP IP CIDR !"))
    password = models.CharField(_(u"password"), max_length=64, blank=True, default=random_string, help_text=_(u"It's recommended to use strong passwords for the endpoint."))
    ha1 = models.CharField(_(u"ha1"), max_length=128, blank=True, default=random_string, help_text=_(u"It's recommended to use strong passwords for the endpoint. md5(username:realm:password)"))
    ha1b = models.CharField(_(u"ha1b"), max_length=128, blank=True, default=random_string, help_text=_(u"It's recommended to use strong passwords for the endpoint. md5(username@domain:realm:password)"))
    rtp_ip = models.CharField(_(u"RTP IP CIDR"), max_length=100, default="auto", help_text=_(u"Internal IP address/mask to bindto for RTP. Format : CIDR Ex. 192.168.1.0/32"))
    sip_ip = models.CharField(_(u"SIP IP CIDR"), max_length=100, null=True, blank=True, validators=[validate_cidr], help_text=_(u"Internal IP address/mask to bind to for SIP. Format : CIDR. Ex. 192.168.1.0/32"))
    sip_port = models.PositiveIntegerField(_(u"SIP port"), default=5060)
    sip_transport = models.CharField(_(u"SIP transport protocol"), max_length=15, default="udp", choices=SIP_TRANSPORT_CHOICES, help_text=_(u"Which transport protocol to use for SIP messages"))
    rtp_transport = models.CharField(_(u"RTP transport protocol"), max_length=15, default="RTP/AVP", choices=RTP_TRANSPORT_CHOICES, help_text=_(u"Which transport protocol to use for RTP packets"))
    rtp_tos = models.PositiveIntegerField(_(u"TOS value for RTP streams"), default=184, choices=TOS_RTP_CHOICES, help_text=_(u"Which TOS value to use for RTP packets"))
    max_calls = models.PositiveIntegerField(_(u'max calls'), default=1, help_text=_(u"max simultaneous calls allowed for this customer account."))
    calls_per_second = models.PositiveIntegerField(_(u'max calls per second'), default=10, help_text=_(u"maximum calls per second allowed for this customer endpoint."))
    outbound_caller_id_name = models.CharField(_(u"callerID name"), max_length=50, blank=True, help_text=_(u"Caller ID name sent to provider on outbound calls."))
    outbound_caller_id_number = models.CharField(_(u"callerID num"), max_length=80, blank=True, help_text=_(u"Caller ID number sent to provider on outbound calls."))
    force_caller_id = models.BooleanField(_(u"force callerID"), default=False)
    masq_caller_id = models.BooleanField(_(u"masq callerID"), default=False)
    pai = models.BooleanField(_(u"caller ID in PAI field"), default=False, help_text=_(u"put callerid in SIP P-Asserted-Id field if enabled"))
    pid = models.BooleanField(_(u"caller ID in PID field"), default=False, help_text=_(u"put callerid in SIP PID field if enabled"))
    ppi = models.BooleanField(_(u"caller ID in PPD field"), default=False, help_text=_(u"put callerid in SIP P-Preferred-Id field if enabled"))
    urgency_number = models.BooleanField(_(u"allow urgency numbers"), default=True, help_text=_(u"You have also to allow global routing option and define an urgency ratecard"))
    insee_code = models.CharField(_(u'special code for routing urgency numbers'), null=True, blank=True, max_length=10, help_text=_(u"Postal code, INSEE code ... for routing urgency number to the right urgency call center."))
    fake_ring = models.BooleanField(_(u"fake ring"), default=False, help_text=_(u"Fake ring : Enabled / Disabled - Send a fake ring to the caller."))
    cli_debug = models.BooleanField(_(u"CLI debug"), default=False, help_text=_(u"CLI debug : Enabled / Disabled - Permit to see all debug messages on cli."))
    transcoding_allowed = models.BooleanField(_(u'allow transcoding calls'), default=False, help_text=_(u"If enabled, calls could be transcoded. be careful, as it is an expensive cpu task."))
    recording_allowed = models.BooleanField(_(u'allow recording calls'), default=False, help_text=_(u"If enabled, calls could be recorded. be careful on available space."))
    recording_always = models.BooleanField(_(u'record all calls'), default=False, help_text=_(u"If enabled, all calls will be recorded. be careful on available space."))
    recording_limit = models.PositiveIntegerField(_(u'recording space storage'), default=30, help_text=_(u"how many Mo will be available for recording storage."))
    recording_retention = models.PositiveIntegerField(_(u'retention days for recording'), default=30, help_text=_(u"how many days a recording will be available. After, it will be deleted by automatic job"))
    description = models.TextField(_(u'description'), blank=True)

    # Relationship Fields
    customer = models.ForeignKey(
        Customer,
        on_delete=models.CASCADE, related_name="customers", verbose_name=_(u"customer")
    )
    callerid_norm = models.ForeignKey(
        NormalizationGrp,
        on_delete=models.CASCADE, related_name='calleridnormrules_c', null=True, blank=True, verbose_name=_(u"CallerID normalization rules for outbound call")
    )
    callee_norm = models.ForeignKey(
        NormalizationGrp,
        on_delete=models.CASCADE, related_name='caleenormrules_c', null=True, blank=True, verbose_name=_(u"Destination number normalization rules for outbound call")
    )
    callerid_norm_in = models.ForeignKey(
        NormalizationGrp,
        on_delete=models.CASCADE, related_name='calleridnormrulesin_c', null=True, blank=True, verbose_name=_(u"CallerID normalization rules for inbound call")
    )
    callee_norm_in = models.ForeignKey(
        NormalizationGrp,
        on_delete=models.CASCADE, related_name='caleenormrulesin_c', null=True, blank=True, verbose_name=_(u"Destination number normalization rules for inbound call")
    )
    domain = models.ForeignKey(
        Domain,
        on_delete=models.CASCADE, related_name='domain_edp', verbose_name=_(u"SIP Domain")
    )
    codec_list = models.ManyToManyField(
        Codec, blank=True,
        related_name="codecs_c",
        help_text=_(u"if NULL, all available codecs are allowed")
    )


    class Meta:
        db_table = 'pyfb_endpoint_customer'
        ordering = ('customer', 'name')
        verbose_name = _(u'customer endpoint')
        verbose_name_plural = _(u'customer endpoints')
        indexes = [
            PartialIndex(fields=['name', 'callerid_norm'], unique=True, where_postgresql='enabled = True'),
            PartialIndex(fields=['name', 'callee_norm'], unique=True, where_postgresql='enabled = True'),
            PartialIndex(fields=['name', 'callerid_norm_in'], unique=True, where_postgresql='enabled = True'),
            PartialIndex(fields=['name', 'callee_norm_in'], unique=True, where_postgresql='enabled = True'),
        ]

    def __str__(self):
        return "%s (%s:%s)" % (self.name, self.sip_ip, self.sip_port)

    def get_absolute_url(self):
        return reverse('pyfb-endpoint:pyfb_endpoint_customerendpoint_detail', args=(self.pk,))

    def get_update_url(self):
        return reverse('pyfb-endpoint:pyfb_endpoint_customerendpoint_update', args=(self.pk,))

    def clean(self):
        if (self.registration and
                (self.password is None or self.password == '')):
            raise ValidationError(_(u"""You have to specify a password if you
                                  want to allow registration"""))
        if (self.registration is False and
                (self.sip_ip is None or self.sip_ip == '')):
            raise ValidationError(_(u"""You must specify a SIP IP CIDR if you do
                                  not want to use registration"""))
        if self.registration and self.password:
            # in future use https://github.com/dstufft/django-passwords ?
            MIN_LENGTH = 8
            if len(self.password) < MIN_LENGTH:
                raise ValidationError(_(u"""The password must be at least %d
                                      characters long.""") % MIN_LENGTH)
            first_isalpha = self.password[0].isalpha()
            if all(c.isalpha() == first_isalpha for c in self.password):
                raise ValidationError(_(u"""The new password must contain
                                            at least one letter and at least
                                            one digit"""))
        if self.sip_ip:
            m = re.search('/32$', self.sip_ip)
            if m:
                pass
            elif len(IPNetwork(self.sip_ip)) == 1:
                self.sip_ip = str(self.sip_ip) + str('/32')
                # add name check no space ...


class ProviderEndpoint(TimeStampedModel):

    # Choices
    SIP_TRANSPORT_CHOICES = Choices(
        'udp',
        'tcp',
        'tls'
    )
    RTP_TRANSPORT_CHOICES = Choices(
        'RTP/AVP',
    )
    TOS_RTP_CHOICES = Choices(
        # reference : https://en.wikipedia.org/wiki/Type_of_service
        (0, '0 - CS0 - 0 Best effort'),
        (160, '160 - CS5 - 5 Critical'),
        (184, '184 - EF - 5 Critical'),
    )

    # Fields
    name = models.CharField(_(u"name"), max_length=64, unique=True)
    enabled = models.BooleanField(_(u"enabled / disabled"), default=True)
    register = models.BooleanField(_(u"register"), default=False)
    username = models.CharField(_(u"username"), blank=True, default='', max_length=35)
    password = models.CharField(_(u"password"), blank=True, default='', max_length=64)
    realm = models.CharField(_(u"realm"), max_length=64, blank=True, default="", help_text=_(u"Authentication realm. Same as gateway name, if blank."))
    from_domain = models.CharField(_(u"from domain"), max_length=50, blank=True, default="", help_text=_(u"Domain to use in from field. Same as realm if blank."))
    expire_seconds = models.PositiveIntegerField(_(u"expire seconds"), default=3600, null=True)
    retry_seconds = models.PositiveIntegerField(_(u"retry seconds"), default=30, null=True, help_text=_(u"How many seconds before a retry when a failure or timeout occurs"))
    max_calls = models.PositiveIntegerField(_(u'max calls'), default=30, help_text=_(u"max simultaneous calls allowed for this customer account."))
    calls_per_second = models.PositiveIntegerField(_(u'max calls per second'), default=10, help_text=_(u"maximum calls per second allowed for this gateway."))
    sip_proxy = models.CharField(_(u"proxy"), max_length=128, default="", help_text=_(u"IP if register is False."))
    sip_transport = models.CharField(_(u"SIP transport protocol"), max_length=15, default="udp", choices=SIP_TRANSPORT_CHOICES, help_text=_(u"Which transport to use for SIP messages"))
    sip_port = models.PositiveIntegerField(_(u"SIP port"), default="5060", help_text=_(u"Gateway SIP port - Default 5060 -."))
    rtp_transport = models.CharField(_(u"RTP transport protocol"), max_length=15, default="RTP/AVP", choices=RTP_TRANSPORT_CHOICES, help_text=_(u"Which transport protocol to use for RTP packets"))
    rtp_tos = models.PositiveIntegerField(_(u"TOS value for RTP streams"), default=184, choices=TOS_RTP_CHOICES, help_text=_(u"Which TOS value to use for RTP packets"))
    prefix = models.CharField(_(u'prefix'), blank=True, default='', max_length=15)
    suffix = models.CharField(_(u'suffix'), blank=True, default='', max_length=15)
    caller_id_in_from = models.BooleanField(_(u"caller ID in From field"), default=True, help_text=_(u"Use the callerid of an inbound call in the from field on outbound calls via this gateway."))
    add_plus_in_caller = models.BooleanField(_(u"add + in caller ID"), default=False, help_text=_(u"Add a + in front of the callerid number for outbound calls via this gateway."))
    pid = models.BooleanField(_(u"caller ID in PID field"), default=False, help_text=_(u"put callerid in SIP PID field if enabled"))
    pai = models.BooleanField(_(u"caller ID in PAI field"), default=False, help_text=_(u"put callerid in SIP P-Asserted-Id field if enabled"))
    ppi = models.BooleanField(_(u"caller ID in PPD field"), default=False, help_text=_(u"put callerid in SIP P-Preferred-Id field if enabled"))

    # Relationship Fields
    provider = models.ForeignKey(
        Provider,
        on_delete=models.CASCADE, related_name="providers_p", verbose_name=_(u"Provider")
    )
    callerid_norm = models.ForeignKey(
        NormalizationGrp,
        on_delete=models.CASCADE, related_name='calleridnormrules_p', null=True, blank=True, verbose_name=_(u"CallerID normalization rules for outbound call")
    )
    callee_norm = models.ForeignKey(
        NormalizationGrp,
        on_delete=models.CASCADE, related_name='caleenormrules_p', null=True, blank=True, verbose_name=_(u"Destination number normalization rules for outbound call")
    )
    callerid_norm_in = models.ForeignKey(
        NormalizationGrp,
        on_delete=models.CASCADE, related_name='calleridnormrulesin_p', null=True, blank=True, verbose_name=_(u"CallerID normalization rules for inbound call")
    )
    callee_norm_in = models.ForeignKey(
        NormalizationGrp,
        on_delete=models.CASCADE, related_name='caleenormrulesin_p', null=True, blank=True, verbose_name=_(u"Destination number normalization rules for inbound call")
    )
    codec_list = models.ManyToManyField(
        Codec, blank=True,
        related_name="codecs_p",
        help_text=_(u"if NULL, all available codecs are allowed")
    )
    uacreg = models.OneToOneField(
        UacReg,
        related_name="uac_reg",
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        help_text=_(u"Must be set if registration is needed")
    )

    class Meta:
        db_table = 'pyfb_endpoint_provider'
        ordering = ('provider', 'name')
        verbose_name = _(u'provider endpoint')
        verbose_name_plural = _(u'provider endpoints')
        indexes = [
            PartialIndex(fields=['name', 'callerid_norm'], unique=True, where_postgresql='enabled = True'),
            PartialIndex(fields=['name', 'callee_norm'], unique=True, where_postgresql='enabled = True'),
            PartialIndex(fields=['name', 'callerid_norm_in'], unique=True, where_postgresql='enabled = True'),
            PartialIndex(fields=['name', 'callee_norm_in'], unique=True, where_postgresql='enabled = True'),
        ]

    def __str__(self):
        return u'%s' % self.name

    def get_absolute_url(self):
        return reverse('pyfb-endpoint:pyfb_endpoint_providerendpoint_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('pyfb-endpoint:pyfb_endpoint_providerendpoint_update', args=(self.pk,))



from django.core.exceptions import ValidationError
from django.utils.translation import ugettext_lazy as _

from netaddr import IPNetwork, AddrFormatError

import re


def validate_cidr(value):
    if value:
        try:
            cidr_val = IPNetwork(value)
            m = re.search('/32$', value)
            if m:
                return IPNetwork(cidr_val)
            elif len(cidr_val) == 1:
                return str(cidr_val) + str('/32')
            else:
                return IPNetwork(cidr_val)
        except AddrFormatError as e:
            raise ValidationError(str(e))



# -*- coding: utf-8 -*-
from django.views.generic import DetailView, ListView, UpdateView, CreateView
from .models import CustomerEndpoint, Codec, ProviderEndpoint
from .forms import CustomerEndpointForm, CodecForm, ProviderEndpointForm


class CustomerEndpointListView(ListView):
    model = CustomerEndpoint


class CustomerEndpointCreateView(CreateView):
    model = CustomerEndpoint
    form_class = CustomerEndpointForm


class CustomerEndpointDetailView(DetailView):
    model = CustomerEndpoint


class CustomerEndpointUpdateView(UpdateView):
    model = CustomerEndpoint
    form_class = CustomerEndpointForm


class CodecListView(ListView):
    model = Codec


class CodecCreateView(CreateView):
    model = Codec
    form_class = CodecForm


class CodecDetailView(DetailView):
    model = Codec


class CodecUpdateView(UpdateView):
    model = Codec
    form_class = CodecForm


class ProviderEndpointListView(ListView):
    model = ProviderEndpoint


class ProviderEndpointCreateView(CreateView):
    model = ProviderEndpoint
    form_class = ProviderEndpointForm


class ProviderEndpointDetailView(DetailView):
    model = ProviderEndpoint


class ProviderEndpointUpdateView(UpdateView):
    model = ProviderEndpoint
    form_class = ProviderEndpointForm



# Generated by Django 2.1.4 on 2018-12-18 16:31

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import model_utils.fields
import partial_index
import pyfb_endpoint.models
import pyfb_endpoint.validators


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('pyfb_normalization', '0001_initial'),
        ('pyfb_company', '0004_auto_20181210_1138'),
    ]

    operations = [
        migrations.CreateModel(
            name='Codec',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='name')),
                ('number', models.PositiveIntegerField()),
                ('ptime', models.PositiveIntegerField()),
                ('stereo', models.BooleanField(default=False)),
                ('rfc_name', models.CharField(max_length=30, unique=True)),
                ('description', models.TextField(max_length=100)),
            ],
            options={
                'ordering': ('-name',),
            },
        ),
        migrations.CreateModel(
            name='CustomerEndpoint',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('name', models.CharField(help_text='Ex.: customer SIP username, etc...', max_length=50, unique=True, verbose_name='username')),
                ('enabled', models.BooleanField(default=True, verbose_name='enabled / disabled')),
                ('registration', models.BooleanField(default=True, help_text='Is registration needed for calling ? True, the phone needs to register with correct username/password. If false, you must specify a CIDR in SIP IP CIDR !', verbose_name='registration')),
                ('password', models.CharField(blank=True, default=pyfb_endpoint.models.random_string, help_text="It's recommended to use strong passwords for the endpoint.", max_length=64, verbose_name='password')),
                ('ha1', models.CharField(blank=True, default=pyfb_endpoint.models.random_string, help_text="It's recommended to use strong passwords for the endpoint. md5(username:realm:password)", max_length=128, verbose_name='ha1')),
                ('ha1b', models.CharField(blank=True, default=pyfb_endpoint.models.random_string, help_text="It's recommended to use strong passwords for the endpoint. md5(username@domain:realm:password)", max_length=128, verbose_name='ha1b')),
                ('rtp_ip', models.CharField(default='auto', help_text='Internal IP address/mask to bindto for RTP. Format : CIDR Ex. 192.168.1.0/32', max_length=100, verbose_name='RTP IP CIDR')),
                ('sip_ip', models.CharField(blank=True, help_text='Internal IP address/mask to bind to for SIP. Format : CIDR. Ex. 192.168.1.0/32', max_length=100, null=True, validators=[pyfb_endpoint.validators.validate_cidr], verbose_name='SIP IP CIDR')),
                ('sip_port', models.PositiveIntegerField(default=5060, verbose_name='SIP port')),
                ('sip_transport', models.CharField(choices=[('udp', 'udp'), ('tcp', 'tcp'), ('tls', 'tls')], default='udp', help_text='Which transport protocol to use for SIP messages', max_length=15, verbose_name='SIP transport protocol')),
                ('rtp_transport', models.CharField(choices=[('RTP/AVP', 'RTP/AVP')], default='RTP/AVP', help_text='Which transport protocol to use for RTP packets', max_length=15, verbose_name='RTP transport protocol')),
                ('rtp_tos', models.PositiveIntegerField(choices=[(0, '0 - CS0 - 0 Best effort'), (160, '160 - CS5 - 5 Critical'), (184, '184 - EF - 5 Critical')], default=184, help_text='Which TOS value to use for RTP packets', verbose_name='TOS value for RTP streams')),
                ('max_calls', models.TextField(default=1, help_text='max simultaneous calls allowed for this customer account.', verbose_name='max calls')),
                ('calls_per_second', models.TextField(default=10, help_text='maximum calls per second allowed for this customer endpoint.', verbose_name='max calls per second')),
                ('outbound_caller_id_name', models.CharField(blank=True, help_text='Caller ID name sent to provider on outbound calls.', max_length=50, verbose_name='callerID name')),
                ('outbound_caller_id_number', models.CharField(blank=True, help_text='Caller ID number sent to provider on outbound calls.', max_length=80, verbose_name='callerID num')),
                ('force_caller_id', models.BooleanField(default=False, verbose_name='force callerID')),
                ('masq_caller_id', models.BooleanField(default=False, verbose_name='masq callerID')),
                ('pai', models.BooleanField(default=False, help_text='put callerid in SIP PAI field if enabled', verbose_name='caller ID in PAI field')),
                ('pid', models.BooleanField(default=False, help_text='put callerid in SIP PID field if enabled', verbose_name='caller ID in PID field')),
                ('urgency_number', models.BooleanField(default=True, help_text='You have also to allow global routing option and define an urgency ratecard', verbose_name='allow urgency numbers')),
                ('insee_code', models.CharField(blank=True, help_text='Postal code, INSEE code ... for routing urgency number to the right urgency call center.', max_length=10, null=True, verbose_name='special code for routing urgency numbers')),
                ('fake_ring', models.BooleanField(default=False, help_text='Fake ring : Enabled / Disabled - Send a fake ring to the caller.', verbose_name='fake ring')),
                ('cli_debug', models.BooleanField(default=False, help_text='CLI debug : Enabled / Disabled - Permit to see all debug messages on cli.', verbose_name='CLI debug')),
                ('transcoding_allowed', models.BooleanField(default=False, help_text='If enabled, calls could be transcoded. be careful, as it is an expensive cpu task.', verbose_name='allow transcoding calls')),
                ('recording_allowed', models.BooleanField(default=False, help_text='If enabled, calls could be recorded. be careful on available space.', verbose_name='allow recording calls')),
                ('recording_always', models.BooleanField(default=False, help_text='If enabled, all calls will be recorded. be careful on available space.', verbose_name='record all calls')),
                ('recording_limit', models.PositiveIntegerField(default=30, help_text='how many Mo will be available for recording storage.', verbose_name='recording space storage')),
                ('recording_retention', models.PositiveIntegerField(default=30, help_text='how many days a recording will be available. After, it will be deleted by automatic job', verbose_name='retention days for recording')),
                ('description', models.TextField(blank=True, verbose_name='description')),
                ('callee_norm', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='caleenormrules_c', to='pyfb_normalization.NormalizationGrp', verbose_name='Destination number normalization rules for outbound call')),
                ('callee_norm_in', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='caleenormrulesin_c', to='pyfb_normalization.NormalizationGrp', verbose_name='Destination number normalization rules for inbound call')),
                ('callerid_norm', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='calleridnormrules_c', to='pyfb_normalization.NormalizationGrp', verbose_name='CallerID normalization rules for outbound call')),
                ('callerid_norm_in', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='calleridnormrulesin_c', to='pyfb_normalization.NormalizationGrp', verbose_name='CallerID normalization rules for inbound call')),
                ('codec_list', models.ManyToManyField(related_name='codecs_c', to='pyfb_endpoint.Codec')),
                ('customer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='customers', to='pyfb_company.Customer', verbose_name='customer')),
            ],
            options={
                'ordering': ('customer', 'name'),
                'db_table': 'pyfb_endpoint_customer',
                'verbose_name_plural': 'customer endpoints',
                'verbose_name': 'customer endpoint',
            },
        ),
        migrations.CreateModel(
            name='ProviderEndpoint',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('name', models.CharField(max_length=64, unique=True, verbose_name='name')),
                ('enabled', models.BooleanField(default=True, verbose_name='enabled / disabled')),
                ('username', models.CharField(blank=True, default='', max_length=35, verbose_name='username')),
                ('password', models.CharField(blank=True, default='', max_length=64, verbose_name='password')),
                ('register', models.BooleanField(default=False, verbose_name='register')),
                ('realm', models.CharField(blank=True, default='', help_text='Authentication realm. Same as gateway name, if blank.', max_length=64, verbose_name='realm')),
                ('from_domain', models.CharField(blank=True, default='', help_text='Domain to use in from field. Same as realm if blank.', max_length=50, verbose_name='from domain')),
                ('expire_seconds', models.PositiveIntegerField(default=3600, null=True, verbose_name='expire seconds')),
                ('retry_seconds', models.PositiveIntegerField(default=30, help_text='How many seconds before a retry when a failure or timeout occurs', null=True, verbose_name='retry seconds')),
                ('max_calls', models.PositiveIntegerField(default=30, help_text='max simultaneous calls allowed for this customer account.', verbose_name='max calls')),
                ('calls_per_second', models.PositiveIntegerField(default=10, help_text='maximum calls per second allowed for this gateway.', verbose_name='max calls per second')),
                ('sip_proxy', models.CharField(default='', help_text='IP if register is False.', max_length=128, verbose_name='proxy')),
                ('sip_transport', models.CharField(choices=[('udp', 'udp'), ('tcp', 'tcp'), ('tls', 'tls')], default='udp', help_text='Which transport to use for SIP messages', max_length=15, verbose_name='SIP transport protocol')),
                ('sip_port', models.PositiveIntegerField(default='5060', help_text='Gateway SIP port - Default 5060 -.', verbose_name='SIP port')),
                ('rtp_transport', models.CharField(choices=[('RTP/AVP', 'RTP/AVP')], default='RTP/AVP', help_text='Which transport protocol to use for RTP packets', max_length=15, verbose_name='RTP transport protocol')),
                ('rtp_tos', models.PositiveIntegerField(choices=[(0, '0 - CS0 - 0 Best effort'), (160, '160 - CS5 - 5 Critical'), (184, '184 - EF - 5 Critical')], default=184, help_text='Which TOS value to use for RTP packets', verbose_name='TOS value for RTP streams')),
                ('prefix', models.CharField(blank=True, default='', max_length=15, verbose_name='prefix')),
                ('suffix', models.CharField(blank=True, default='', max_length=15, verbose_name='suffix')),
                ('caller_id_in_from', models.BooleanField(default=True, help_text='Use the callerid of an inbound call in the from field on outbound calls via this gateway.', verbose_name='caller ID in From field')),
                ('pid', models.BooleanField(default=False, help_text='put callerid in SIP PID field if enabled', verbose_name='caller ID in PID field')),
                ('pai', models.BooleanField(default=False, help_text='put callerid in SIP PAI field if enabled', verbose_name='caller ID in PAI field')),
                ('callee_norm', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='caleenormrules_p', to='pyfb_normalization.NormalizationGrp', verbose_name='Destination number normalization rules for outbound call')),
                ('callee_norm_in', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='caleenormrulesin_p', to='pyfb_normalization.NormalizationGrp', verbose_name='Destination number normalization rules for inbound call')),
                ('callerid_norm', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='calleridnormrules_p', to='pyfb_normalization.NormalizationGrp', verbose_name='CallerID normalization rules for outbound call')),
                ('callerid_norm_in', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='calleridnormrulesin_p', to='pyfb_normalization.NormalizationGrp', verbose_name='CallerID normalization rules for inbound call')),
                ('codec_list', models.ManyToManyField(related_name='codecs_p', to='pyfb_endpoint.Codec')),
                ('provider', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='providers_p', to='pyfb_company.Provider', verbose_name='Provider')),
            ],
            options={
                'ordering': ('provider', 'name'),
                'db_table': 'pyfb_endpoint_provider',
                'verbose_name_plural': 'provider endpoints',
                'verbose_name': 'provider endpoint',
            },
        ),
        migrations.AddIndex(
            model_name='providerendpoint',
            index=partial_index.PartialIndex(fields=['name', 'callerid_norm'], name='pyfb_endpoi_name_6e3cf8_partial', unique=True, where_postgresql='enabled = True', where_sqlite=''),
        ),
        migrations.AddIndex(
            model_name='providerendpoint',
            index=partial_index.PartialIndex(fields=['name', 'callee_norm'], name='pyfb_endpoi_name_e54096_partial', unique=True, where_postgresql='enabled = True', where_sqlite=''),
        ),
        migrations.AddIndex(
            model_name='providerendpoint',
            index=partial_index.PartialIndex(fields=['name', 'callerid_norm_in'], name='pyfb_endpoi_name_3ead03_partial', unique=True, where_postgresql='enabled = True', where_sqlite=''),
        ),
        migrations.AddIndex(
            model_name='providerendpoint',
            index=partial_index.PartialIndex(fields=['name', 'callee_norm_in'], name='pyfb_endpoi_name_48168f_partial', unique=True, where_postgresql='enabled = True', where_sqlite=''),
        ),
        migrations.AddIndex(
            model_name='customerendpoint',
            index=partial_index.PartialIndex(fields=['name', 'callerid_norm'], name='pyfb_endpoi_name_3a00d3_partial', unique=True, where_postgresql='enabled = True', where_sqlite=''),
        ),
        migrations.AddIndex(
            model_name='customerendpoint',
            index=partial_index.PartialIndex(fields=['name', 'callee_norm'], name='pyfb_endpoi_name_f5c867_partial', unique=True, where_postgresql='enabled = True', where_sqlite=''),
        ),
        migrations.AddIndex(
            model_name='customerendpoint',
            index=partial_index.PartialIndex(fields=['name', 'callerid_norm_in'], name='pyfb_endpoi_name_0079d2_partial', unique=True, where_postgresql='enabled = True', where_sqlite=''),
        ),
        migrations.AddIndex(
            model_name='customerendpoint',
            index=partial_index.PartialIndex(fields=['name', 'callee_norm_in'], name='pyfb_endpoi_name_d7f6c3_partial', unique=True, where_postgresql='enabled = True', where_sqlite=''),
        ),
    ]



# Generated by Django 2.1.8 on 2019-05-23 17:17

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0009_auto_20190523_1647'),
        ('pyfb_endpoint', '0009_auto_20190410_1549'),
    ]

    operations = [
        migrations.AddField(
            model_name='customerendpoint',
            name='domain',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='domain_edp', to='pyfb_kamailio.Domain', verbose_name='SIP Domain'),
            preserve_default=False,
        ),
    ]



# Generated by Django 2.1.5 on 2019-04-10 15:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_endpoint', '0007_auto_20190410_1544'),
    ]

    operations = [
        migrations.RenameField(
            model_name='providerendpoint',
            old_name='ppd',
            new_name='ppi',
        ),
    ]



from . import models

from rest_framework import serializers


class CustomerEndpointSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.CustomerEndpoint
        fields = (
            'pk', 
            'registration', 
            'password', 
            'description', 
            'name', 
            'rtp_ip', 
            'sip_ip', 
            'sip_port', 
            'max_calls', 
            'calls_per_second', 
            'outbound_caller_id_name', 
            'outbound_caller_id_number', 
            'force_caller_id', 
            'masq_caller_id', 
            'urgency_number', 
            'insee_code', 
            'enabled', 
            'fake_ring', 
            'cli_debug', 
            'created', 
            'modified', 
            'transcoding_allowed', 
            'recording_allowed', 
            'recording_always', 
            'recording_limit', 
            'recording_retention', 
            'sip_transport', 
            'rtp_transport', 
            'rtp_tos', 
            'pai', 
            'pid', 
            'ha1', 
            'ha1b', 
        )


class CodecSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.Codec
        fields = (
            'pk', 
            'name', 
            'created', 
            'modified', 
            'number', 
            'ptime', 
            'stereo', 
            'rfc_name', 
            'description', 
        )


class ProviderEndpointSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.ProviderEndpoint
        fields = (
            'pk', 
            'name', 
            'created', 
            'modified', 
            'max_calls', 
            'enabled', 
            'prefix', 
            'suffix', 
            'username', 
            'password', 
            'register', 
            'sip_proxy', 
            'sip_transport', 
            'sip_port', 
            'realm', 
            'from_domain', 
            'expire_seconds', 
            'retry_seconds', 
            'caller_id_in_from',
            'add_plus_in_caller',
            'pid', 
            'pai', 
            'calls_per_second', 
            'rtp_transport', 
            'rtp_tos', 
        )





# Generated by Django 2.1.4 on 2018-12-19 13:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_endpoint', '0002_auto_20181218_1700'),
    ]

    operations = [
        migrations.AlterField(
            model_name='codec',
            name='description',
            field=models.TextField(blank=True, max_length=100, verbose_name='description'),
        ),
        migrations.AlterField(
            model_name='codec',
            name='number',
            field=models.PositiveIntegerField(help_text='payload types (PT) for audio encodings', unique=True, verbose_name='payload number'),
        ),
        migrations.AlterField(
            model_name='codec',
            name='ptime',
            field=models.PositiveIntegerField(verbose_name='ptime'),
        ),
        migrations.AlterField(
            model_name='codec',
            name='rfc_name',
            field=models.CharField(help_text='format is important !.', max_length=30, unique=True, verbose_name='rfc name'),
        ),
        migrations.AlterField(
            model_name='codec',
            name='stereo',
            field=models.BooleanField(default=False, verbose_name='is stereo ?'),
        ),
        migrations.AlterField(
            model_name='customerendpoint',
            name='codec_list',
            field=models.ManyToManyField(blank=True, null=True, related_name='codecs_c', to='pyfb_endpoint.Codec'),
        ),
        migrations.AlterField(
            model_name='providerendpoint',
            name='codec_list',
            field=models.ManyToManyField(blank=True, null=True, related_name='codecs_p', to='pyfb_endpoint.Codec'),
        ),
    ]



# Generated by Django 2.2.11 on 2020-03-21 15:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_endpoint', '0014_auto_20190710_1456'),
    ]

    operations = [
        migrations.AddField(
            model_name='providerendpoint',
            name='add_plus_in_caller',
            field=models.BooleanField(default=False, help_text='Add a + in front of the callerid number for outbound calls via this gateway.', verbose_name='add + in caller ID'),
        ),
    ]



# Generated by Django 2.1.5 on 2019-04-10 15:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_endpoint', '0006_auto_20190130_1427'),
    ]

    operations = [
        migrations.AddField(
            model_name='customerendpoint',
            name='ppd',
            field=models.BooleanField(default=False, help_text='put callerid in SIP P-Prefered-Id field if enabled', verbose_name='caller ID in PPD field'),
        ),
        migrations.AddField(
            model_name='providerendpoint',
            name='ppd',
            field=models.BooleanField(default=False, help_text='put callerid in SIP P-Prefered-Id field if enabled', verbose_name='caller ID in PPD field'),
        ),
    ]



# Generated by Django 2.1.5 on 2019-04-10 15:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_endpoint', '0008_auto_20190410_1547'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='customerendpoint',
            name='ppd',
        ),
        migrations.AddField(
            model_name='customerendpoint',
            name='ppi',
            field=models.BooleanField(default=False, help_text='put callerid in SIP P-Preferred-Id field if enabled', verbose_name='caller ID in PPD field'),
        ),
        migrations.AlterField(
            model_name='customerendpoint',
            name='pai',
            field=models.BooleanField(default=False, help_text='put callerid in SIP P-Asserted-Id field if enabled', verbose_name='caller ID in PAI field'),
        ),
        migrations.AlterField(
            model_name='providerendpoint',
            name='pai',
            field=models.BooleanField(default=False, help_text='put callerid in SIP P-Asserted-Id field if enabled', verbose_name='caller ID in PAI field'),
        ),
        migrations.AlterField(
            model_name='providerendpoint',
            name='ppi',
            field=models.BooleanField(default=False, help_text='put callerid in SIP P-Preferred-Id field if enabled', verbose_name='caller ID in PPD field'),
        ),
    ]



# Generated by Django 2.1.4 on 2018-12-19 14:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_endpoint', '0003_auto_20181219_1354'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customerendpoint',
            name='codec_list',
            field=models.ManyToManyField(blank=True, help_text='if NULL, all available codecs are allowed', related_name='codecs_c', to='pyfb_endpoint.Codec'),
        ),
        migrations.AlterField(
            model_name='providerendpoint',
            name='codec_list',
            field=models.ManyToManyField(blank=True, help_text='if NULL, all available codecs are allowed', related_name='codecs_p', to='pyfb_endpoint.Codec'),
        ),
    ]



# -*- coding: utf-8 -*-
from django.urls import path, include
from rest_framework import routers

from . import api
from . import views


app_name = 'pyfb-endpoint'

router = routers.DefaultRouter()
router.register(r'customerendpoint', api.CustomerEndpointViewSet)
router.register(r'codec', api.CodecViewSet)
router.register(r'providerendpoint', api.ProviderEndpointViewSet)


urlpatterns = (
    # urls for Django Rest Framework API
    path('api/v1/', include(router.urls)),
)

urlpatterns += (
    # urls for CustomerEndpoint
    path('pyfb_endpoint/customerendpoint/', views.CustomerEndpointListView.as_view(), name='pyfb_endpoint_customerendpoint_list'),
    path('pyfb_endpoint/customerendpoint/create/', views.CustomerEndpointCreateView.as_view(), name='pyfb_endpoint_customerendpoint_create'),
    path('pyfb_endpoint/customerendpoint/detail/<int:pk>/', views.CustomerEndpointDetailView.as_view(), name='pyfb_endpoint_customerendpoint_detail'),
    path('pyfb_endpoint/customerendpoint/update/<int:pk>/', views.CustomerEndpointUpdateView.as_view(), name='pyfb_endpoint_customerendpoint_update'),
)

urlpatterns += (
    # urls for Codec
    path('pyfb_endpoint/codec/', views.CodecListView.as_view(), name='pyfb_endpoint_codec_list'),
    path('pyfb_endpoint/codec/create/', views.CodecCreateView.as_view(), name='pyfb_endpoint_codec_create'),
    path('pyfb_endpoint/codec/detail/<int:pk>/', views.CodecDetailView.as_view(), name='pyfb_endpoint_codec_detail'),
    path('pyfb_endpoint/codec/update/<int:pk>/', views.CodecUpdateView.as_view(), name='pyfb_endpoint_codec_update'),
)

urlpatterns += (
    # urls for ProviderEndpoint
    path('pyfb_endpoint/providerendpoint/', views.ProviderEndpointListView.as_view(), name='pyfb_endpoint_providerendpoint_list'),
    path('pyfb_endpoint/providerendpoint/create/', views.ProviderEndpointCreateView.as_view(), name='pyfb_endpoint_providerendpoint_create'),
    path('pyfb_endpoint/providerendpoint/detail/<int:pk>/', views.ProviderEndpointDetailView.as_view(), name='pyfb_endpoint_providerendpoint_detail'),
    path('pyfb_endpoint/providerendpoint/update/<int:pk>/', views.ProviderEndpointUpdateView.as_view(), name='pyfb_endpoint_providerendpoint_update'),
)



# Generated by Django 2.1.4 on 2018-12-18 17:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_endpoint', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customerendpoint',
            name='calls_per_second',
            field=models.PositiveIntegerField(default=10, help_text='maximum calls per second allowed for this customer endpoint.', verbose_name='max calls per second'),
        ),
        migrations.AlterField(
            model_name='customerendpoint',
            name='max_calls',
            field=models.PositiveIntegerField(default=1, help_text='max simultaneous calls allowed for this customer account.', verbose_name='max calls'),
        ),
    ]



from . import models
from . import serializers
from rest_framework import viewsets, permissions


class CustomerEndpointViewSet(viewsets.ModelViewSet):
    """ViewSet for the CustomerEndpoint class"""

    queryset = models.CustomerEndpoint.objects.all()
    serializer_class = serializers.CustomerEndpointSerializer
    permission_classes = [permissions.IsAuthenticated]


class CodecViewSet(viewsets.ModelViewSet):
    """ViewSet for the Codec class"""

    queryset = models.Codec.objects.all()
    serializer_class = serializers.CodecSerializer
    permission_classes = [permissions.IsAuthenticated]


class ProviderEndpointViewSet(viewsets.ModelViewSet):
    """ViewSet for the ProviderEndpoint class"""

    queryset = models.ProviderEndpoint.objects.all()
    serializer_class = serializers.ProviderEndpointSerializer
    permission_classes = [permissions.IsAuthenticated]





# Generated by Django 2.1.5 on 2019-01-30 14:27

from django.db import migrations

def initialize_data(apps, schema_editor):
    data = [
        {"model": "pyfb_endpoint.codec", "pk": 2, "fields": {"created": "2018-12-18T16:35:57.289Z", "modified": "2018-12-18T17:27:13.316Z", "name": "G.711u", "number": 0, "ptime": 20, "stereo": 0, "rfc_name": "PCMU", "description": "ITU-T G.711 PCM \u00b5-Law audio 64 kbit/s"}}, {"model": "pyfb_endpoint.codec", "pk": 3, "fields": {"created": "2018-12-18T16:36:21.657Z", "modified": "2018-12-18T17:28:49.068Z", "name": "G.729", "number": 18, "ptime": 20, "stereo": 0, "rfc_name": "G729", "description": "ITU-T G.729 and G.729a audio 8 kbit/s; Annex B is implied unless the annexb=no parameter is used"}}, {"model": "pyfb_endpoint.codec", "pk": 4, "fields": {"created": "2018-12-18T17:24:17.056Z", "modified": "2018-12-18T17:27:41.528Z", "name": "G.711a", "number": 8, "ptime": 20, "stereo": 0, "rfc_name": "PCMA", "description": "ITU-T G.711 PCM A-Law audio 64 kbit/s"}}, {"model": "pyfb_endpoint.codec", "pk": 5, "fields": {"created": "2018-12-18T17:24:52.732Z", "modified": "2018-12-18T17:45:34.900Z", "name": "GSM", "number": 3, "ptime": 20, "stereo": 0, "rfc_name": "GSM", "description": "European GSM Full Rate audio 13 kbit/s"}}, {"model": "pyfb_endpoint.codec", "pk": 7, "fields": {"created": "2018-12-18T17:30:57.733Z", "modified": "2018-12-18T17:30:57.737Z", "name": "G.723", "number": 4, "ptime": 30, "stereo": 0, "rfc_name": "G723", "description": "ITU-T G.723.1 audio"}}, {"model": "pyfb_endpoint.codec", "pk": 8, "fields": {"created": "2018-12-18T17:31:36.092Z", "modified": "2018-12-18T17:31:36.098Z", "name": "G.722", "number": 9, "ptime": 20, "stereo": 0, "rfc_name": "G722", "description": "ITU-T G.722 audio 64 kbit/s"}}
    ]

    for record in data:
        app_name, model_name = record['model'].split('.')
        ModelClass = apps.get_model(app_name, model_name)
        obj = ModelClass(**record['fields'])
        # this is required only if you have other models
        # with foreign keys referring to this object
        # obj.pk = record['pk']
        obj.save()


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_endpoint', '0005_auto_20190130_1417'),
    ]

    operations = [
        migrations.RunPython(initialize_data),
    ]



# Generated by Django 2.1.8 on 2019-07-10 14:52

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0009_auto_20190523_1647'),
        ('pyfb_endpoint', '0012_auto_20190710_1448'),
    ]

    operations = [
        migrations.AddField(
            model_name='customerendpoint',
            name='uacreg',
            field=models.OneToOneField(blank=True, help_text='Must be set if registration is needed', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='uac_reg', to='pyfb_kamailio.UacReg'),
        ),
        migrations.RemoveField(
            model_name='customerendpoint',
            name='codec_list',
        ),
        migrations.AddField(
            model_name='customerendpoint',
            name='codec_list',
            field=models.ManyToManyField(blank=True, help_text='if NULL, all available codecs are allowed', related_name='codecs_c', to='pyfb_endpoint.Codec'),
        ),
    ]



# -*- coding: utf-8 -*-
from django.contrib import admin
from django import forms
from django.utils.translation import ugettext_lazy as _

from .models import CustomerEndpoint, Codec, ProviderEndpoint


class CustomerEndpointAdminForm(forms.ModelForm):

    class Meta:
        model = CustomerEndpoint
        fields = '__all__'


class CustomerEndpointAdmin(admin.ModelAdmin):
    form = CustomerEndpointAdminForm
    list_display = ['name', 'domain', 'customer', 'registration', 'sip_ip', 'max_calls', 'calls_per_second', 'enabled']
    readonly_fields = ['created', 'modified', 'ha1', 'ha1b']
    ordering = ['customer', 'enabled', 'name']
    list_filter = ['enabled']
    search_fields = ['^sip_ip', '^customer__company__name', '^name']
    save_on_top = True
    exclude = ['ha1', 'ha1b']
    affix = True
    fieldsets = (
        (_(u'general'), {
            'fields': (('customer',
                        'enabled'),
                       ('registration','password'),
                       ('name', 'domain'),
                       'codec_list',
                       'transcoding_allowed',),
            'description': _(u'general sip account informations')
        }),
        (_(u'IP Settings'), {
            'fields': (('sip_ip', 'sip_port', 'sip_transport'),
                       'rtp_ip', 'rtp_transport', 'rtp_tos'),
            'classes': ('collapse',),
            'description': _(u'If no registration, SIP IP CIDR is needed')
        }),
        (_(u'caller/callee settings'), {
            'fields': (('outbound_caller_id_name',
                        'outbound_caller_id_number'),
                       ('force_caller_id','masq_caller_id'),
                       ('pai', 'ppi', 'pid'),
                       ('callerid_norm', 'callerid_norm_in'),
                       ('callee_norm', 'callee_norm_in'),),
            'classes': ('collapse',),
            'description': _(u'caller/callee parameters')
        }),
        (_(u'limit settings'), {
            'fields': ('max_calls',
                       'calls_per_second'),
            'classes': ('collapse',),
            'description': _(u'limit settings')
        }),
        (_(u'recording settings'), {
            'fields': (('recording_allowed',
                       'recording_always'),
                       ('recording_limit',
                       'recording_retention'),),
            'classes': ('collapse',),
            'description': _(u'recording parameters')
        }),
        (_(u'advanced settings'), {
            'fields': ('fake_ring',
                       'cli_debug'),
            'classes': ('collapse',),
            'description': _(u'advanced parameters')
        }),
        # (_(u'Urgency settings'), {
        #     'fields': ('urgency_numbr',
        #                'insee_code'),
        #     'classes': ('collapse',),
        #     'description': _(u'Urgency routing numbers parameters')
        # }),
        (_(u'more'), {
            'fields': ('description',
                       ('created', 'modified'),),
            'classes': ('collapse',),
            'description': _(u'more informations')
        }),
    )

admin.site.register(CustomerEndpoint, CustomerEndpointAdmin)


class CodecAdminForm(forms.ModelForm):

    class Meta:
        model = Codec
        fields = '__all__'


class CodecAdmin(admin.ModelAdmin):
    form = CodecAdminForm
    list_display = ['name', 'number', 'ptime', 'stereo', 'rfc_name']
    # readonly_fields = ['created', 'modified', 'number', 'ptime', 'stereo', 'rfc_name', 'description']

admin.site.register(Codec, CodecAdmin)


class ProviderEndpointAdminForm(forms.ModelForm):

    class Meta:
        model = ProviderEndpoint
        fields = '__all__'


class ProviderEndpointAdmin(admin.ModelAdmin):
    form = ProviderEndpointAdminForm
    list_display = ['name', 'provider', 'register', 'sip_proxy', 'prefix', 'max_calls', 'calls_per_second', 'enabled']
    readonly_fields = ['created', 'modified']
    ordering = ['provider', 'enabled', 'name']
    list_filter = ['enabled']
    search_fields = ['^sip_proxy', '^provider__company__name', '^name']
    save_on_top = True
    affix = True
    fieldsets = (
        (_(u'general'), {
            'fields': (('name', 'provider', 'enabled'),
                       ('sip_proxy', 'register'),
                       ('uacreg'),
                       #('username', 'password'),
                       #'realm',
                       #'from_domain',
                       #('expire_seconds', 'retry_seconds'),
                       ('prefix', 'suffix'),
                       'codec_list',),
            'description': _(u'general sip account informations')
        }),
        (_(u'protocol settings'), {
            'fields': (('sip_port', 'sip_transport'),
                       ('rtp_transport', 'rtp_tos')),
            'classes': ('collapse',),
            'description': _(u'If no registration, SIP IP CIDR is needed')
        }),
        (_(u'caller/callee settings'), {
            'fields': (('add_plus_in_caller'),
                       ('caller_id_in_from', 'pai', 'ppi', 'pid'),
                       ('callerid_norm', 'callerid_norm_in'),
                       ('callee_norm', 'callee_norm_in'),),
            'classes': ('collapse',),
            'description': _(u'caller/callee parameters')
        }),
        (_(u'limit settings'), {
            'fields': ('max_calls',
                       'calls_per_second'),
            'classes': ('collapse',),
            'description': _(u'limit settings')
        }),
        (_(u'more'), {
            'fields': (('created', 'modified'),),
            'classes': ('collapse',),
            'description': _(u'more informations')
        }),
    )

admin.site.register(ProviderEndpoint, ProviderEndpointAdmin)



# Generated by Django 2.1.8 on 2019-05-23 17:29

from django.db import migrations
import migrate_sql.operations


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_endpoint', '0010_customerendpoint_domain'),
    ]

    operations = [
        migrate_sql.operations.ReverseAlterSQL(
            name='subscriber_view',
            sql='DROP VIEW IF EXISTS subscriber CASCADE; ',
            reverse_sql="DROP VIEW IF EXISTS subscriber CASCADE; CREATE OR REPLACE VIEW subscriber AS  SELECT row_number() OVER () AS id,  c.name AS username,  CAST('' AS VARCHAR) AS domain,  c.password FROM pyfb_endpoint_customer c WHERE c.enabled=True and c.registration=True;",
        ),
        migrate_sql.operations.AlterSQL(
            name='subscriber_view',
            sql='DROP VIEW IF EXISTS subscriber CASCADE; CREATE OR REPLACE VIEW subscriber AS  SELECT row_number() OVER () AS id,  c.name AS username,  d.domain AS domain,  c.password FROM pyfb_endpoint_customer c LEFT JOIN domain d  ON c.domain_id = d.id WHERE c.enabled=True and c.registration=True;',
            reverse_sql='DROP VIEW IF EXISTS subscriber CASCADE; ',
        ),
    ]



from migrate_sql.config import SQLItem

sql_items = [
    SQLItem(
        'subscriber_view',   # name of the item
        'DROP VIEW IF EXISTS subscriber CASCADE; '
        'CREATE OR REPLACE VIEW subscriber AS'
        '  SELECT row_number() OVER () AS id,'
        '  c.name AS username,'
        '  d.domain AS domain,'
        '  c.password '
        'FROM pyfb_endpoint_customer c '
        'LEFT JOIN domain d '
        ' ON c.domain_id = d.id '
        'WHERE c.enabled=True and c.registration=True;'
        '',  # forward sql
        reverse_sql='DROP VIEW IF EXISTS subscriber CASCADE; ',  # sql for removal
    ),
    SQLItem(
        'address_view',   # name of the item
        'DROP VIEW IF EXISTS address CASCADE; '
        'CREATE OR REPLACE VIEW address AS'
        ' SELECT row_number() OVER () AS id, * FROM ('
        '  SELECT'
        '  1 AS grp,'
        '  CAST(LEFT(CAST(c.sip_ip AS VARCHAR), LENGTH(CAST(c.sip_ip AS VARCHAR)) - 3) AS VARCHAR) AS ip_addr,'
        '  CAST(RIGHT(CAST(c.sip_ip AS VARCHAR), 2) AS INTEGER) AS mask,'
        '  CAST(c.sip_port AS INTEGER) AS port,'
        '  CAST(c.name AS VARCHAR) AS tag '
        'FROM pyfb_endpoint_customer c '
        'WHERE c.enabled=True and c.registration=False '
        'UNION ALL '
        'SELECT'
        '  10 AS grp,'
        '  CAST(sg.sip_proxy AS VARCHAR) AS ip_addr,'
        '  32 AS mask,'
        '  CAST(sg.sip_port AS INTEGER) AS port,'
        '  sg.name AS tag '
        'FROM pyfb_endpoint_provider sg '
        'WHERE sg.enabled=True and sg.register=False) v;'
        '',  # forward sql
        reverse_sql='DROP VIEW IF EXISTS address CASCADE ',  # sql for removal
    ),
    SQLItem(
        'usrpref_view',   # name of the item
        'DROP VIEW IF EXISTS usr_preferences CASCADE; '
        'CREATE OR REPLACE VIEW usr_preferences AS'
        ' SELECT row_number() OVER () AS id, * FROM ('
        '  SELECT DISTINCT'
        '  c.name AS uuid,'
        '  c.name AS username,'
        '  CAST(\'\' AS VARCHAR) AS domain,'
        '  CAST(\'grpnormcallee\' AS VARCHAR) AS attribute,'
        '  CAST(1 AS INT) AS type,'
        '  CAST(nrg.dpid_id AS VARCHAR) AS value,'
        '  CAST(now() AS timestamp without time zone) AS last_modified '
        'FROM pyfb_endpoint_customer c '
        'INNER JOIN pyfb_normalization_grp ng '
        '  ON ng.id = c.callee_norm_id '
        'INNER JOIN pyfb_normalization_rule_grp nrg'
        '  ON nrg.dpid_id = ng.id '
        'WHERE c.enabled=True '
        'UNION ALL '
        '  SELECT DISTINCT'
        '  c.name AS uuid,'
        '  c.name AS username,'
        '  CAST(\'\' AS VARCHAR) AS domain,'
        '  CAST(\'grpnormcaller\' AS VARCHAR) AS attribute,'
        '  CAST(1 AS INT) AS type,'
        '  CAST(nrg.dpid_id AS VARCHAR) AS value,'
        '  CAST(now() AS timestamp without time zone) AS last_modified '
        'FROM pyfb_endpoint_customer c '
        'INNER JOIN pyfb_normalization_grp ng '
        '  ON ng.id = c.callerid_norm_id '
        'INNER JOIN pyfb_normalization_rule_grp nrg'
        '  ON nrg.dpid_id = ng.id '
        'WHERE c.enabled=True '
        'UNION ALL '
        '  SELECT DISTINCT'
        '  c.name AS uuid,'
        '  c.name AS username,'
        '  CAST(\'\' AS VARCHAR) AS domain,'
        '  CAST(\'grpnormcalleein\' AS VARCHAR) AS attribute,'
        '  CAST(1 AS INT) AS type,'
        '  CAST(nrg.dpid_id AS VARCHAR) AS value,'
        '  CAST(now() AS timestamp without time zone) AS last_modified '
        'FROM pyfb_endpoint_customer c '
        'INNER JOIN pyfb_normalization_grp ng '
        '  ON ng.id = c.callee_norm_in_id '
        'INNER JOIN pyfb_normalization_rule_grp nrg'
        '  ON nrg.dpid_id = ng.id '
        'WHERE c.enabled=True '
        'UNION ALL '
        '  SELECT DISTINCT'
        '  c.name AS uuid,'
        '  c.name AS username,'
        '  CAST(\'\' AS VARCHAR) AS domain,'
        '  CAST(\'grpnormcallerin\' AS VARCHAR) AS attribute,'
        '  CAST(1 AS INT) AS type,'
        '  CAST(nrg.dpid_id AS VARCHAR) AS value,'
        '  CAST(now() AS timestamp without time zone) AS last_modified '
        'FROM pyfb_endpoint_customer c '
        'INNER JOIN pyfb_normalization_grp ng '
        '  ON ng.id = c.callerid_norm_in_id '
        'INNER JOIN pyfb_normalization_rule_grp nrg'
        '  ON nrg.dpid_id = ng.id '
        'WHERE c.enabled=True '
        'UNION ALL '
        '  SELECT DISTINCT'
        '  c.name AS uuid,'
        '  c.name AS username,'
        '  CAST(\'\' AS VARCHAR) AS domain,'
        '  CAST(\'routinggrp\' AS VARCHAR) AS attribute,'
        '  CAST(1 AS INT) AS type,'
        '  CAST(r.routinggroup_id AS VARCHAR) AS value,'
        '  CAST(now() AS timestamp without time zone) AS last_modified '
        'FROM pyfb_endpoint_customer c '
        'INNER JOIN pyfb_routing_c_routinggrp r '
        '  ON r.customer_id = c.customer_id '
        'WHERE c.enabled=True) v; '
        '',  # forward sql
        reverse_sql='DROP VIEW IF EXISTS usr_preferences CASCADE; ',  # sql for removal
    ),
]

# DROP VIEW IF EXISTS subscriber CASCADE; CREATE OR REPLACE VIEW subscriber AS  SELECT row_number() OVER () AS id,  c.name AS username,  CAST('' AS VARCHAR) AS domain,  c.password FROM pyfb_endpoint_customer c WHERE c.enabled=True and c.registration=True;

# DROP VIEW IF EXISTS address CASCADE; CREATE OR REPLACE VIEW address AS SELECT row_number() OVER () AS id, * FROM (  SELECT  1 AS grp,  CAST(LEFT(CAST(c.sip_ip AS VARCHAR), LENGTH(CAST(c.sip_ip AS VARCHAR)) - 3) AS VARCHAR) AS ip_addr,  CAST(RIGHT(CAST(c.sip_ip AS VARCHAR), 2) AS INTEGER) AS mask,  CAST(c.sip_port AS INTEGER) AS port,  CAST(c.name AS VARCHAR) AS tag FROM pyfb_endpoint_customer c WHERE c.enabled=True and c.registration=False UNION ALL SELECT  10 AS grp,  CAST(sg.sip_proxy AS VARCHAR) AS ip_addr,  32 AS mask,  CAST(sg.sip_port AS INTEGER) AS port,  sg.name AS tag FROM pyfb_endpoint_provider sg WHERE sg.enabled=True and sg.register=False) v;

# DROP VIEW IF EXISTS usr_preferences CASCADE; CREATE OR REPLACE VIEW usr_preferences AS SELECT row_number() OVER () AS id, * FROM ( SELECT DISTINCT c.name AS uuid, c.name AS username, CAST('' AS VARCHAR) AS domain, CAST('grpnormcallee' AS VARCHAR) AS attribute, CAST(1 AS INT) AS type, CAST(nrg.dpid_id AS VARCHAR) AS value, CAST(now() AS timestamp without time zone) AS last_modified FROM pyfb_endpoint_customer c INNER JOIN pyfb_normalization_grp ng ON ng.id = c.callee_norm_id INNER JOIN pyfb_normalization_rule_grp nrg ON nrg.dpid_id = ng.id WHERE c.enabled=True UNION ALL SELECT DISTINCT c.name AS uuid, c.name AS username, CAST('' AS VARCHAR) AS domain, CAST('grpnormcaller' AS VARCHAR) AS attribute, CAST(1 AS INT) AS type, CAST(nrg.dpid_id AS VARCHAR) AS value, CAST(now() AS timestamp without time zone) AS last_modified FROM pyfb_endpoint_customer c INNER JOIN pyfb_normalization_grp ng ON ng.id = c.callerid_norm_id INNER JOIN pyfb_normalization_rule_grp nrg ON nrg.dpid_id = ng.id WHERE c.enabled=True UNION ALL SELECT DISTINCT c.name AS uuid, c.name AS username, CAST('' AS VARCHAR) AS domain, CAST('grpnormcalleein' AS VARCHAR) AS attribute, CAST(1 AS INT) AS type, CAST(nrg.dpid_id AS VARCHAR) AS value, CAST(now() AS timestamp without time zone) AS last_modified FROM pyfb_endpoint_customer c INNER JOIN pyfb_normalization_grp ng ON ng.id = c.callee_norm_in_id INNER JOIN pyfb_normalization_rule_grp nrg ON nrg.dpid_id = ng.id WHERE c.enabled=True UNION ALL SELECT DISTINCT c.name AS uuid, c.name AS username, CAST('' AS VARCHAR) AS domain, CAST('grpnormcallerin' AS VARCHAR) AS attribute, CAST(1 AS INT) AS type, CAST(nrg.dpid_id AS VARCHAR) AS value, CAST(now() AS timestamp without time zone) AS last_modified FROM pyfb_endpoint_customer c INNER JOIN pyfb_normalization_grp ng ON ng.id = c.callerid_norm_in_id INNER JOIN pyfb_normalization_rule_grp nrg ON nrg.dpid_id = ng.id WHERE c.enabled=True UNION ALL SELECT DISTINCT c.name AS uuid, c.name AS username, CAST('' AS VARCHAR) AS domain, CAST('routinggrp' AS VARCHAR) AS attribute, CAST(1 AS INT) AS type, CAST(r.routinggroup_id AS VARCHAR) AS value, CAST(now() AS timestamp without time zone) AS last_modified FROM pyfb_endpoint_customer c INNER JOIN pyfb_routing_c_routinggrp r ON r.customer_id = c.customer_id) v;
